==> subtitleeditor_0.10.1.orig.tar.gz: subtitleeditor-0.10.1/src/DialogScale.h <==
#ifndef _DialogScale_h
#define _DialogScale_h

/*
 *	subtitle editor
 *
 *	http://kitone.free.fr/subtitleeditor/
 *
 *	Copyright @ 2005-2006, kitone
 *
 *	Contact: kitone at free dot fr
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public
 *	License as published by the Free Software Foundation; either
 *	version 2 of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public
 *	License along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 *
 *	See gpl.txt for more information regarding the GNU General Public License.
 *
 *
 *	\file
 *	\brief 
 *	\author kitone (kitone at free dot fr)
 */

#include <libglademm/xml.h>
#include <gtkmm/dialog.h>
#include <gtkmm/spinbutton.h>
#include <gtkmm/entry.h>

#include "ISubtitleEditor.h"


class DialogScale : public Gtk::Dialog
{
public:
	DialogScale(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);

	void execute();
protected:
	void on_spin1_changed();
	void on_spin2_changed();

	void on_entry1_changed();
	void on_entry2_changed();
protected:
	Glib::RefPtr<SubtitleModel> m_model;

	Gtk::SpinButton*	m_spinSource1;
	Gtk::Entry*				m_entryDest1;

	Gtk::SpinButton*	m_spinSource2;
	Gtk::Entry*				m_entryDest2;
};

#endif//_DialogScale_h

==> subtitleeditor_0.11.0.orig.tar.gz: subtitleeditor-0.11.0/src/DialogScale.h <==
#ifndef _DialogScale_h
#define _DialogScale_h

/*
 *	subtitle editor
 *
 *	http://kitone.free.fr/subtitleeditor/
 *
 *	Copyright @ 2005-2006, kitone
 *
 *	Contact: kitone at free dot fr
 *
 *	This program is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU General Public
 *	License as published by the Free Software Foundation; either
 *	version 2 of the License, or (at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the GNU
 *	General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public
 *	License along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 *
 *	See gpl.txt for more information regarding the GNU General Public License.
 *
 *
 *	\file
 *	\brief 
 *	\author kitone (kitone at free dot fr)
 */

#include <libglademm/xml.h>
#include <gtkmm/dialog.h>
#include <gtkmm/spinbutton.h>
#include <gtkmm/entry.h>

#include "ISubtitleEditor.h"


class DialogScale : public Gtk::Dialog
{
public:
	DialogScale(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);

	void execute();
protected:
	void on_spin1_changed();
	void on_spin2_changed();

	void on_entry1_changed();
	void on_entry2_changed();

protected:

	/*
	 *
	 */
	double calcul_scale(long source1, long dest1, long source2, long dest2);

	/*
	 *
	 */
	SubtitleTime calcul(const SubtitleTime &source, double scale, 
			const SubtitleTime &sourcedisp, const SubtitleTime &destdisp);

	/*
	 *
	 */
	void scale(const SubtitleTime &source1, const SubtitleTime &dest1,
			const SubtitleTime &source2, const SubtitleTime &dest2);

protected:
	Glib::RefPtr<SubtitleModel> m_subtitleModel;

	Gtk::SpinButton*	m_spinSource1;
	Gtk::Entry*				m_entryDest1;

	Gtk::SpinButton*	m_spinSource2;
	Gtk::Entry*				m_entryDest2;
};

#endif//_DialogScale_h
